@@ -1,7 +1,8 @@
+# -*-cperl-*-
 package AFS;
 
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)$Id: AFS.pm 662 2005-02-12 17:14:10Z nog $"
+# RCS-Id: "@(#)$Id: AFS.pm 830 2008-10-04 07:34:00Z nog $"
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
@@ -30,39 +31,12 @@ require Exporter;
 require AutoLoader;
 require DynaLoader;
 
-BEGIN {
-    # insert file ../version
-    # do NOT change here
-sub set_version {
-
-    my $head_url = '$HeadURL: svn+ssh://Sams/afs/mpa/home/nog/SVN-Repositories/afsperl/tags/release-2.2.3/src/AFS.pm $';
-
-    if ($head_url =~ /rc\d/) {
-        # release candidate
-        do{my@r=$head_url=~/\d+/g;sprintf'%d.%d.%d-rc%d',$r[0],$r[1],$r[2],$r[3];};
-    }
-    elsif ($head_url =~ /release/) {
-        # normal release
-        do{my($a,$b)=split(/SVN/,$head_url);my@r=$b=~/\d+/g;sprintf'%d.'.'%d'.'.%d'x($#r-1),@r;};
-    }
-    elsif ($head_url =~ /trunk/) {
-        # development release
-        do{my@r=q/Major Version 2.2 $Rev: 662 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%d'x($#r-1),@r;};
-    }
-    else {
-        # should never happen
-        do{my$a='Unknown Release 9.9.99';};
-    }
-}
-
-}
-
 use vars qw(@ISA $VERSION $REVISION);
 
 @ISA = qw(Exporter AutoLoader DynaLoader);
 
-$VERSION  = set_version();
-$REVISION = do{my@r=q/Major Version 2.2 $Rev: 662 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
+$VERSION = '2.4.1';
+$REVISION = do{my@r=q/Major Version 2.4 $Rev: 830 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
 
 @CELL = qw (
             configdir
@@ -244,8 +218,8 @@ sub cleanacl {
     else { return 0; }
 }
 
-package AFS::PTS_SERVER;
-sub new { AFS::PTS->_new(@_); }
+# package AFS::PTS_SERVER;
+# sub new { AFS::PTS->_new(@_); }
 
 use AFS::KTC_PRINCIPAL;
 # package AFS::KTC_PRINCIPAL;
